@@ -1,6 +1,8 @@
-from typing import Any, Type
+import base64
+from typing import Any, Type, cast
 
-from vial.errors import ErrorHandlingAPI, MethodNotAllowedError, NotFoundError
+from vial.errors import ErrorHandlingAPI
+from vial.exceptions import MethodNotAllowedError, NotFoundError, VialError
 from vial.json import Json, NativeJson
 from vial.loggers import LoggerFactory
 from vial.middleware import CallChain, MiddlewareAPI, MiddlewareChain
@@ -25,10 +27,10 @@ class RouteResolver:
 
     def __call__(self, resources: dict[str, dict[HTTPMethod, Route]], request: Request) -> Route:
         if not (defined_routes := resources.get(request.resource)):
-            raise NotFoundError(f"No route defined for {request.resource}")
+            raise NotFoundError(VialError.ROUTE_NOT_FOUND.get(request.resource))
 
         if not (route := defined_routes.get(request.method)):
-            raise MethodNotAllowedError(f"No route defined for method {request.method.name}")
+            raise MethodNotAllowedError(VialError.METHOD_NOT_ALLOWED.get(request.resource, request.method.name))
 
         return route
 
@@ -68,14 +70,13 @@ class RouteInvoker:
         return args
 
 
-class Resource(RoutingAPI, ParserAPI, MiddlewareAPI):
+class Resource(RoutingAPI, ParserAPI, MiddlewareAPI, ErrorHandlingAPI):
     def __init__(self, name: str) -> None:
-        super().__init__()
+        super().__init__(name)
         self.name = name
 
 
 class Vial(RoutingAPI, ParserAPI, MiddlewareAPI, ErrorHandlingAPI):
-
     route_resolver_class = RouteResolver
 
     route_invoker_class = RouteInvoker
@@ -85,7 +86,7 @@ class Vial(RoutingAPI, ParserAPI, MiddlewareAPI, ErrorHandlingAPI):
     json_class: Type[Json] = NativeJson
 
     def __init__(self, name: str) -> None:
-        super().__init__()
+        super().__init__(name)
         self.name = name
         self.route_resolver = self.route_resolver_class()
         self.invoker = self.route_invoker_class()
@@ -96,6 +97,7 @@ class Vial(RoutingAPI, ParserAPI, MiddlewareAPI, ErrorHandlingAPI):
         self.register_parsers(app)
         self.register_routes(app)
         self.register_middlewares(app)
+        self.register_error_handlers(app)
 
     def __call__(self, event: dict[str, Any], context: LambdaContext) -> dict[str, Any]:
         request = self._build_request(event, context)
@@ -104,12 +106,14 @@ class Vial(RoutingAPI, ParserAPI, MiddlewareAPI, ErrorHandlingAPI):
             return self._to_lambda_response(response)
 
     def _handle_request(self, request: Request) -> Response:
+        route_resource = self.name  # If a route can't be found, default to the global application
         try:
             route = self.route_resolver(self.routes, request)
+            route_resource = route.resource
             return self._build_invocation_chain(route)(request)
         except Exception as e:  # pylint: disable=broad-except
             self.logger.exception("Encountered uncaught exception")
-            return self.default_error_handler(e)
+            return self.default_error_handler(route_resource, e)
 
     def _build_invocation_chain(self, route: Route) -> CallChain:
         def route_invocation(event: Request) -> Response:
@@ -130,8 +134,7 @@ class Vial(RoutingAPI, ParserAPI, MiddlewareAPI, ErrorHandlingAPI):
             body = response.body
         return {"headers": response.headers, "statusCode": response.status, "body": body}
 
-    @staticmethod
-    def _build_request(event: dict[str, Any], context: LambdaContext) -> Request:
+    def _build_request(self, event: dict[str, Any], context: LambdaContext) -> Request:
         return Request(
             event,
             context,
@@ -140,5 +143,12 @@ class Vial(RoutingAPI, ParserAPI, MiddlewareAPI, ErrorHandlingAPI):
             event["path"],
             MultiDict(event["multiValueHeaders"]),
             MultiDict(event["multiValueQueryStringParameters"]),
-            event["body"],
+            self._get_body(event),
         )
+
+    @staticmethod
+    def _get_body(event: dict[str, Any]) -> str:
+        body = event["body"]
+        if event.get("isBase64Encoded") and body:
+            return base64.b64decode(body).decode("utf-8")
+        return cast(str, body)
