@@ -3,10 +3,10 @@ from __future__ import annotations
 from collections import defaultdict
 from dataclasses import dataclass
 from typing import Any, Type
-from urllib.parse import parse_qs, urlparse
+from urllib import parse
 
 from vial.app import Vial
-from vial.errors import NotFoundError
+from vial.exceptions import NotFoundError, VialError
 from vial.json import Json, NativeJson
 from vial.types import HTTPMethod, LambdaContext, Response
 
@@ -23,8 +23,8 @@ class RouteMatcher:
         self.routes = sorted(routes)
 
     def match(self, url: str) -> Match:
-        parsed_url = urlparse(url)
-        query_params = parse_qs(parsed_url.query, keep_blank_values=True)
+        parsed_url = parse.urlparse(url)
+        query_params = parse.parse_qs(parsed_url.query, keep_blank_values=True)
         path = self._remove_trailing_slash(parsed_url.path)
         return self._find_match(url, path.split("/"), query_params)
 
@@ -36,7 +36,7 @@ class RouteMatcher:
 
             if (path_params := self._match_path(parts, url_parts)) is not None:
                 return Match(route_url, path_params, query_params)
-        raise NotFoundError(f"No matching route found for {url}")
+        raise NotFoundError(VialError.ROUTE_NOT_FOUND.get(url))
 
     @staticmethod
     def _match_path(parts: list[str], url_parts: list[str]) -> dict[str, str] | None:
@@ -58,7 +58,6 @@ class RouteMatcher:
 
 
 class Gateway:
-
     json_class: Type[Json] = NativeJson
 
     def __init__(self, app: Vial) -> None:
